@@ -11,33 +11,33 @@ pub mod types;
 pub mod test;
 mod wasm;
 
-pub struct WasmHandlerAPI();
+pub struct WasmHandlerApi();
 
-impl WasmHandlerAPI {
+impl WasmHandlerApi {
     pub const fn onload_symbol() -> &'static str {
         "_wasm_onload"
     }
-    pub fn method_to_symbol(method: Method) -> String {
+    pub fn method_to_symbol(method: WasmMethod) -> String {
         format!("_wasm_handle_{}", method)
     }
-    pub fn symbol_to_method(symbol: &str) -> Option<Method> {
+    pub fn symbol_to_method(symbol: &str) -> Option<WasmMethod> {
         symbol.rsplit(|r| r == '_').next().and_then(|s| s.parse().ok())
     }
 }
 
 #[cfg(test)]
 mod tests {
-    use crate::WasmHandlerAPI;
+    use crate::WasmHandlerApi;
 
     #[test]
     fn method_to_symbol() {
-        let method = WasmHandlerAPI::method_to_symbol(10);
+        let method = WasmHandlerApi::method_to_symbol(10);
         assert_eq!(method, "_wasm_handle_10");
     }
 
     #[test]
     fn symbol_to_method() {
-        let method = WasmHandlerAPI::symbol_to_method("_wasm_handle_10");
+        let method = WasmHandlerApi::symbol_to_method("_wasm_handle_10");
         assert_eq!(method, Some(10));
     }
 }
